cmd

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2026 License: MPL-2.0 Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildRoot

func BuildRoot() *cobra.Command

BuildRoot creates a new root command from the available subcommands.

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func NewCommandCmd

func NewCommandCmd() *cobra.Command

NewCommandCmd defines a command.

func NewCreateCmd

func NewCreateCmd() *cobra.Command

NewCreateCmd defines a command.

func NewDeleteCmd

func NewDeleteCmd() *cobra.Command

NewDeleteCmd defines a command.

func NewDescribeCmd

func NewDescribeCmd() *cobra.Command

NewDescribeCmd defines a command.

func NewInitCmd

func NewInitCmd() *cobra.Command

NewInitCmd defines a command.

func NewRootCmd

func NewRootCmd() *cobra.Command

NewRootCmd returns a new root command.

func NewStartCmd

func NewStartCmd() *cobra.Command

NewStartCmd defines a command.

func NewStatusCmd

func NewStatusCmd() *cobra.Command

NewStatusCmd defines a command.

func NewStopCmd

func NewStopCmd() *cobra.Command

NewStopCmd defines a command.

func NewTokenCmd

func NewTokenCmd() *cobra.Command

NewTokenCmd defines a command.

Types

type CommandCmd

type CommandCmd struct{}

CommandCmd holds the cmd flags.

func (*CommandCmd) Run

func (cmd *CommandCmd) Run(ctx context.Context, options *options.Options) error

Run runs the command logic.

type CreateCmd

type CreateCmd struct{}

CreateCmd holds the cmd flags.

func (*CreateCmd) Run

func (cmd *CreateCmd) Run(ctx context.Context, options *options.Options) error

Run runs the command logic.

type DeleteCmd

type DeleteCmd struct{}

DeleteCmd holds the cmd flags.

func (*DeleteCmd) Run

func (cmd *DeleteCmd) Run(ctx context.Context, options *options.Options) error

Run runs the command logic.

type DescribeCmd

type DescribeCmd struct{}

DescribeCmd holds the cmd flags.

func (*DescribeCmd) Run

func (cmd *DescribeCmd) Run(ctx context.Context, opts *options.Options) error

Run runs the command logic.

type InitCmd

type InitCmd struct{}

InitCmd holds the cmd flags.

func (*InitCmd) Run

func (cmd *InitCmd) Run(ctx context.Context, options *options.Options) error

Run runs the command logic.

type StartCmd

type StartCmd struct{}

StartCmd holds the cmd flags.

func (*StartCmd) Run

func (cmd *StartCmd) Run(ctx context.Context, options *options.Options) error

Run runs the command logic.

type StatusCmd

type StatusCmd struct{}

StatusCmd holds the cmd flags.

func (*StatusCmd) Run

func (cmd *StatusCmd) Run(ctx context.Context, opts *options.Options) error

Run runs the command logic.

type StopCmd

type StopCmd struct {
	Raw bool
}

StopCmd holds the cmd flags.

func (*StopCmd) Run

func (cmd *StopCmd) Run(ctx context.Context, options *options.Options) error

Run runs the command logic.

type TokenCmd

type TokenCmd struct{}

TokenCmd holds the cmd flags.

func (*TokenCmd) Run

func (cmd *TokenCmd) Run(ctx context.Context) error

Run runs the command logic.

Jump to